pub enum DynamoError {
    InvalidListCursor,
    InvalidDynamoCursor,
    SecurableNotFound,
    ShareNotFound {
        share: String,
    },
    SchemaNotFound {
        share: String,
        schema: String,
    },
    TableNotFound {
        share: String,
        schema: String,
        table: String,
    },
    InvalidShareItem,
    InvalidSchemaItem,
    InvalidTableItem,
    ServiceError {
        reason: String,
    },
    Other,
}
Errors that can occur when interacting with the DynamoDB share store.

Variants



InvalidListCursor

The ListCursor could not be interpreted as a DynamoCursor.



InvalidDynamoCursor

The DynamoCursor could not be interpreted as a ListCursor.



SecurableNotFound

The requested securable was not found.



ShareNotFound

Fields

share: String

The name of the share that was not found.

The requested share was not found.



SchemaNotFound

Fields

share: String

The name of the share that was searched.

schema: String

The name of the schema that was not found.

The requested schema was not found.



TableNotFound

Fields

share: String

The name of the share that was searched.

schema: String

The name of the schema that was searched.

table: String

The name of the table that was not found.

The requested table was not found.



InvalidShareItem

The requested share could not be parsed.



InvalidSchemaItem

The requested schema could not be parsed.



InvalidTableItem

The requested table could not be parsed.



ServiceError

Fields

reason: String

The reason for the error.

An error occurred when interacting with the DynamoDB service.



Other

An unexpected error occurred.