pub struct DynamoShareReader { /* private fields */ }
ASSUMPTION: the writer only uses transactions to guarantee the consistency of the shared securables (i.e. share -> schema -> table).

| SHARE#ALL | share1 | … | SHARE#ALL | share2 | … | SHARE#share1 | schema1 | … | SHARE#share1 | schema2 | … | SHARE#share2 | schema1#table1 | … TableManager using AWS DynamoDB to store shared objects.

Table layout

| PK | SK | share_id | storage_path | table_id SHARE#{share_name}#SCHEMA#ALL#TABLE#ALL | SHARE | share1_id SHARE#{share_name}#SCHEMA#{schema_name}#TABLE#ALL | SCHEMA | SHARE#{share_name}#SCHEMA#{schema_name}#TABLE#{table_name} | TABLE | share1_id | s3://my-data-bucket/my-table-root/ | table1_id

Key

  1. KEY: PK+SK
  2. GSI: SK+PK

Implemented query patterns

  1. QUERY on GSI with SK = SHARE
  2. GET on KEY with PK = SHARE#{share_name}#SCHEMA#ALL#TABLE#ALL
  3. QUERY on GSI with SK = SCHEMA AND PK begins_with(SHARE#{share_name})
  4. QUERY on GSI with type = TABLE and SK begins_with(SHARE#{share_name}#SCHEMA#{schema_name})
  5. QUERY on GSI with type = TABLE and SK begins_with(SHARE#{share_name})
  6. GET on KEY with PK = SHARE#{share_name}#SCHEMA#{schema_name}#TABLE#{table_name} AND SK = TABLE

Query patterns

  1. Get a table by share_name, schema_name and table_name
  2. Get a share by share_name
  3. List all shares
  4. List all schemas in a share
  5. List all tables in a share
  6. List all tables in a schema

Implementations

source

impl DynamoShareReader

source

pub fn new(client: Client, table_name: String, index_name: String) -> Self

Create a new TableManager using the AWS DynamoDB client along with table_name and GSI index name.

source

pub fn create_table(&self) -> Result<(), DynamoError>

Create a new DynamoDB table to store shares, schemas and tables.

source

pub fn client(&self) -> &Client

Retrieve underlying DynamoDB SDK client.

source

pub async fn put_share(&self, share: Share) -> Result<Share, DynamoError>

Add a new share to the share store.

source

pub async fn get_share(&self, share_name: &str) -> Result<Share, DynamoError>

Retrieve a share from the share store.

source

pub async fn query_shares( &self, cursor: &ListCursor ) -> Result<List<Share>, DynamoError>

Retrieve a list of shares from the share store.

source

pub async fn put_schema(&self, schema: Schema) -> Result<Schema, DynamoError>

Add a new schema to the share store.

source

pub async fn get_schema( &self, share_name: &str, schema_name: &str ) -> Result<Schema, DynamoError>

Retrieve a schema from the share store.

source

pub async fn query_schemas( &self, share_name: &str, cursor: &ListCursor ) -> Result<List<Schema>, DynamoError>

Retrieve a list of schemas from the share store.

source

pub async fn put_table(&self, table: Table) -> Result<Table, DynamoError>

Add a new table to the share store.

source

pub async fn get_table( &self, share_name: &str, schema_name: &str, table_name: &str ) -> Result<Table, DynamoError>

Retrieve a table from the share store.

source

pub async fn query_tables_in_share( &self, share_name: &str, cursor: &ListCursor ) -> Result<List<Table>, DynamoError>

Retrieve a list of tables from the share store.

source

pub async fn query_tables_in_schema( &self, share_name: &str, schema_name: &str, cursor: &ListCursor ) -> Result<List<Table>, DynamoError>

Retrieve a list of tables from the share store.