pub enum ShareIoError {
ShareNotFound {
share_name: String,
},
SchemaNotFound {
share_name: String,
schema_name: String,
},
TableNotFound {
share_name: String,
schema_name: String,
table_name: String,
},
MalformedContinuationToken,
ConnectionError,
Other {
reason: String,
},
}Expand description
Errors that can occur during the listing and retrieval of shared objects.
Variants
The requested share was not found in the backing store.
SchemaNotFound
Fields
The name of the share where the schema was searched.
The requested schema was not found in the backing store.
TableNotFound
Fields
The name of the share where the table was searched.
The requested table was not found in the backing store.
MalformedContinuationToken
The token in the list cursor could not be serialized.
ConnectionError
The connection to the backing store could not be established.
Other
Other error