Struct delta_sharing_server::protocol::action::Cdf
source · pub struct Cdf {
pub url: String,
pub id: String,
pub partition_values: HashMap<String, Option<String>>,
pub size: u64,
pub stats: Option<String>,
pub version: u64,
pub timestamp: String,
pub expiration_timestamp: Option<String>,
}Expand description
Representation of a data that has changed in the table.
Fields
url: StringAn HTTPS url that a client can use to directly read the data file.
id: StringA unique identifier for the data file in the table.
partition_values: HashMap<String, Option<String>>A map from partition column to value for this file in the table.
size: u64The size of the file in bytes.
stats: Option<String>Summary statistics about the data in this file.
version: u64The table version associated with this file.
timestamp: StringThe unix timestamp in milliseconds corresponding to the table version associated with this file.
expiration_timestamp: Option<String>The unix timestamp in milliseconds corresponding to the expiration of the url associated with this file.