Struct delta_sharing_server::protocol::action::FileBuilder
source · pub struct FileBuilder { /* private fields */ }Expand description
Build a new File action
Implementations
sourceimpl FileBuilder
impl FileBuilder
sourcepub fn new(url: impl Into<String>, id: impl Into<String>) -> Self
pub fn new(url: impl Into<String>, id: impl Into<String>) -> Self
Initialize a new FileBuilder.
sourcepub fn partition_values(
self,
partition_values: HashMap<String, Option<String>>
) -> Self
pub fn partition_values( self, partition_values: HashMap<String, Option<String>> ) -> Self
Set the partition values for this file.
sourcepub fn add_partition_value(
self,
partition: impl Into<String>,
value: Option<impl Into<String>>
) -> Self
pub fn add_partition_value( self, partition: impl Into<String>, value: Option<impl Into<String>> ) -> Self
Add a partition value for this file.
sourcepub fn expiration_timestamp(self, ts: impl Into<String>) -> Self
pub fn expiration_timestamp(self, ts: impl Into<String>) -> Self
Set the expiration timestamp for the url belonging to this file. This is only relevant for urls that have been presigned.