pub struct Metadata { /* private fields */ }
Representation of the table metadata.

The metadata of a table contains all the information required to correctly interpret the data files of the table.

Implementations

source

impl Metadata

source

pub fn id(&self) -> &str

Retrieve the unique table identifier.

source

pub fn name(&self) -> Option<&str>

Retrieve the table name provided by the user.

source

pub fn description(&self) -> Option<&str>

Retrieve the table description provided by the user.

source

pub fn format(&self) -> &FileFormat

Retrieve the specification of the table format.

source

pub fn schema_string(&self) -> &str

Retrieve the schema of the table, serialized as a string.

source

pub fn partition_columns(&self) -> &[String]

Retrieve an array of column names that are used to partition the table.

source

pub fn configuration(&self) -> &HashMap<String, String>

Retrieve a map containing configuration options for the table.

source

pub fn version(&self) -> Option<&str>

Retrieve the version of the table this metadata corresponds to.

source

pub fn size(&self) -> Option<u64>

Retrieve the size of the table in bytes.

source

pub fn num_files(&self) -> Option<u64>

Retrieve the number of files in the table.