pub struct Protocol { /* private fields */ }
Representation of the table protocol.

Protocol versioning will allow servers to exclude older clients that are missing features required to correctly interpret their response if the Delta Sharing Protocol evolves in the future. The protocol version will be increased whenever non-backwards-compatible changes are made to the protocol. When a client is running an unsupported protocol version, it should show an error message instructing the user to upgrade to a newer version of their client.

Implementations

source

impl Protocol

source

pub fn min_reader_version(&self) -> u32

Retrieve the minimum version of the protocol that the client must implement to read this table.