☰
Module securable
Structs
?
Module
delta_sharing_server
::
protocol
::
securable
source
·
[
−
]
Basic types for describing shared objects
Structs
Schema
The type of a schema as defined in the Delta Sharing protocol.
SchemaBuilder
Builder for
Schema
.
Share
The type of a share as defined in the Delta Sharing protocol.
ShareBuilder
Builder for
Share
.
Table
The type of a table as defined in the Delta Sharing protocol.
TableBuilder
Builder for
Table