Struct delta_sharing_server::protocol::securable::Share
source · pub struct Share { /* private fields */ }Expand description
The type of a share as defined in the Delta Sharing protocol.
A share is a logical grouping to share with recipients. A share can be shared with one or multiple recipients. A recipient can access all resources in a share. A share may contain multiple schemas.
Implementations