pub struct ListCursor { /* private fields */ }
Type for pagination through a collection of shared objects.

Implementations

source

impl ListCursor

source

pub fn new(max_results: Option<u32>, page_token: Option<String>) -> Self

Create a new ListCursor with the given max_results and page_token

source

pub fn max_results(&self) -> Option<u32>

Retrieve the maximum amount of objects that should be fetched.

Example
use delta_sharing_server::protocol::share::ListCursor;

let cursor = ListCursor::new(Some(3), None);
assert_eq!(cursor.max_results(), Some(3));
source

pub fn page_token(&self) -> Option<&str>

Retrieve the index from where to resume fetching.

Example
use delta_sharing_server::protocol::share::ListCursor;

let cursor = ListCursor::new(None, Some(String::from("page1")));
assert_eq!(cursor.page_token(), Some("page1"));
source

pub fn has_page_token(&self) -> bool

Check whether or not this cursor is in the middle of fetching.

Example
use delta_sharing_server::protocol::share::ListCursor;

let cursor = ListCursor::new(None, Some(String::from("page1")));
assert!(cursor.has_page_token());

let cursor = ListCursor::new(None, None);
assert!(!cursor.has_page_token());