Types for table info request/response

Structs

Enums

  • A representation of data or mutation in a table reachable with a presigned url.
  • A representation of data or mutation in a table referenced using an object store url.
  • Requested table version.
  • Requested range of table version.

Type Definitions