Enum delta_sharing_server::protocol::table::VersionRange
source · pub enum VersionRange {
Version {
start: u64,
end: u64,
},
Timestamp {
start: DateTime<Utc>,
end: DateTime<Utc>,
},
}Expand description
Requested range of table version.
Variants
Version
Fields
Range of table versions represented by start and end version number.
Timestamp
Fields
Range of table versions represented by start and end timestamp.