Module delta_sharing_server::reader
source · Expand description
Types and traits for reading table data in object storage.
Modules
- Table reader implementation for the Delta Lake format.
Enums
- Error that occur during the reading of the table format.
Traits
- Trait for reading a specific table format from cloud storage.