Struct delta_sharing_server::state::SharingServerState
source · pub struct SharingServerState { /* private fields */ }Expand description
State of the sharing server.
Implementations
sourceimpl SharingServerState
impl SharingServerState
sourcepub fn new(manager: Arc<dyn ShareReader>) -> Self
pub fn new(manager: Arc<dyn ShareReader>) -> Self
Create a new sharing server state.
sourcepub fn add_table_reader(
&mut self,
format: impl Into<String>,
reader: Arc<dyn TableReader>
)
pub fn add_table_reader( &mut self, format: impl Into<String>, reader: Arc<dyn TableReader> )
Add a table reader to the state.
sourcepub fn add_url_signer(
&mut self,
storage: impl Into<String>,
signer: Arc<dyn UrlSigner>
)
pub fn add_url_signer( &mut self, storage: impl Into<String>, signer: Arc<dyn UrlSigner> )
Add a url signer to the state.
sourcepub fn set_table_readers(
&mut self,
readers: HashMap<String, Arc<dyn TableReader>>
)
pub fn set_table_readers( &mut self, readers: HashMap<String, Arc<dyn TableReader>> )
Set the table readers.
sourcepub fn set_url_signers(&mut self, signers: HashMap<String, Arc<dyn UrlSigner>>)
pub fn set_url_signers(&mut self, signers: HashMap<String, Arc<dyn UrlSigner>>)
Set the url signers.
sourcepub fn table_manager(&self) -> Arc<dyn ShareReader>
pub fn table_manager(&self) -> Arc<dyn ShareReader>
Get the share rearder.
sourcepub fn table_reader(&self, format: &str) -> Option<Arc<dyn TableReader>>
pub fn table_reader(&self, format: &str) -> Option<Arc<dyn TableReader>>
Get the table reader for a specific format.
sourcepub fn url_signer(&self, storage: &str) -> Option<Arc<dyn UrlSigner>>
pub fn url_signer(&self, storage: &str) -> Option<Arc<dyn UrlSigner>>
Get the url signer for a specific object store.
Get a list of shares in the share store.
Get a share from the share store.
sourcepub async fn list_schemas(
&self,
share_name: &str,
cursor: &ListCursor
) -> Result<ListSchemasResponse, ServerError>
pub async fn list_schemas( &self, share_name: &str, cursor: &ListCursor ) -> Result<ListSchemasResponse, ServerError>
Get a list of schemas in a share.
Get a list of tables in a share.
sourcepub async fn list_tables_in_schema(
&self,
share_name: &str,
schema_name: &str,
cursor: &ListCursor
) -> Result<ListTablesResponse, ServerError>
pub async fn list_tables_in_schema( &self, share_name: &str, schema_name: &str, cursor: &ListCursor ) -> Result<ListTablesResponse, ServerError>
Get a list of tables in a schema.
sourcepub async fn get_table_version(
&self,
share_name: &str,
schema_name: &str,
table_name: &str,
version: Version
) -> Result<TableVersionResponse, ServerError>
pub async fn get_table_version( &self, share_name: &str, schema_name: &str, table_name: &str, version: Version ) -> Result<TableVersionResponse, ServerError>
Get the version of a table.
sourcepub async fn get_table_metadata(
&self,
share_name: &str,
schema_name: &str,
table_name: &str
) -> Result<TableActionsResponse, ServerError>
pub async fn get_table_metadata( &self, share_name: &str, schema_name: &str, table_name: &str ) -> Result<TableActionsResponse, ServerError>
Get the metadata of a table.
sourcepub async fn get_table_data(
&self,
share_name: &str,
schema_name: &str,
table_name: &str,
_version: Version
) -> Result<TableActionsResponse, ServerError>
pub async fn get_table_data( &self, share_name: &str, schema_name: &str, table_name: &str, _version: Version ) -> Result<TableActionsResponse, ServerError>
Get the data files of a table version.