Struct delta_sharing_server::protocol::action::Metadata
source · pub struct Metadata { /* private fields */ }Expand description
Representation of the table metadata.
The metadata of a table contains all the information required to correctly interpret the data files of the table.
Implementations
sourceimpl Metadata
impl Metadata
sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Retrieve the table description provided by the user.
sourcepub fn format(&self) -> &FileFormat
pub fn format(&self) -> &FileFormat
Retrieve the specification of the table format.
sourcepub fn schema_string(&self) -> &str
pub fn schema_string(&self) -> &str
Retrieve the schema of the table, serialized as a string.
sourcepub fn partition_columns(&self) -> &[String]
pub fn partition_columns(&self) -> &[String]
Retrieve an array of column names that are used to partition the table.
sourcepub fn configuration(&self) -> &HashMap<String, String>
pub fn configuration(&self) -> &HashMap<String, String>
Retrieve a map containing configuration options for the table.