Struct delta_sharing_server::protocol::action::Protocol
source · pub struct Protocol { /* private fields */ }Expand description
Representation of the table protocol.
Protocol versioning will allow servers to exclude older clients that are missing features required to correctly interpret their response if the Delta Sharing Protocol evolves in the future. The protocol version will be increased whenever non-backwards-compatible changes are made to the protocol. When a client is running an unsupported protocol version, it should show an error message instructing the user to upgrade to a newer version of their client.
Implementations