Struct delta_sharing_server::protocol::share::ListCursor
source · pub struct ListCursor { /* private fields */ }Expand description
Type for pagination through a collection of shared objects.
Implementations
sourceimpl ListCursor
impl ListCursor
sourcepub fn new(max_results: Option<u32>, page_token: Option<String>) -> Self
pub fn new(max_results: Option<u32>, page_token: Option<String>) -> Self
Create a new ListCursor with the given max_results and page_token
sourcepub fn max_results(&self) -> Option<u32>
pub fn max_results(&self) -> Option<u32>
Retrieve the maximum amount of objects that should be fetched.
Example
use delta_sharing_server::protocol::share::ListCursor;
let cursor = ListCursor::new(Some(3), None);
assert_eq!(cursor.max_results(), Some(3));sourcepub fn page_token(&self) -> Option<&str>
pub fn page_token(&self) -> Option<&str>
Retrieve the index from where to resume fetching.
Example
use delta_sharing_server::protocol::share::ListCursor;
let cursor = ListCursor::new(None, Some(String::from("page1")));
assert_eq!(cursor.page_token(), Some("page1"));sourcepub fn has_page_token(&self) -> bool
pub fn has_page_token(&self) -> bool
Check whether or not this cursor is in the middle of fetching.
Example
use delta_sharing_server::protocol::share::ListCursor;
let cursor = ListCursor::new(None, Some(String::from("page1")));
assert!(cursor.has_page_token());
let cursor = ListCursor::new(None, None);
assert!(!cursor.has_page_token());Trait Implementations
sourceimpl Clone for ListCursor
impl Clone for ListCursor
sourcefn clone(&self) -> ListCursor
fn clone(&self) -> ListCursor
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ListCursor
impl Debug for ListCursor
sourceimpl Default for ListCursor
impl Default for ListCursor
sourcefn default() -> ListCursor
fn default() -> ListCursor
Returns the “default value” for a type. Read more
sourceimpl<'de> Deserialize<'de> for ListCursor
impl<'de> Deserialize<'de> for ListCursor
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for ListCursor
impl Hash for ListCursor
sourceimpl PartialEq<ListCursor> for ListCursor
impl PartialEq<ListCursor> for ListCursor
sourcefn eq(&self, other: &ListCursor) -> bool
fn eq(&self, other: &ListCursor) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for ListCursor
impl Serialize for ListCursor
impl Eq for ListCursor
impl StructuralEq for ListCursor
impl StructuralPartialEq for ListCursor