pub enum UnsignedDataFile {
File(File),
Add(Add),
Cdf(Cdf),
Remove(Remove),
}Expand description
A representation of data or mutation in a table referenced using an object store url.
A table is represented as a set of files that together are the full table. Every data file has a reference to the underlying object store in its url field.
Variants
File(File)
A file containing data part of the table.
Add(Add)
A file containing data that was added to the table in this version.
Cdf(Cdf)
A file containing data that was changed in this version of the table.
Remove(Remove)
A file containing data that was removed since the last table version.